#!/bin/bash
set -e

export MODULE_GIT_REPO=https://gitlab.ost.ch/ins-courses/autpy/notebooks.git
export MODULE_FOLDER="AutPy"

pull_repository() {
    local repoUrl=${1:?"No repository URL set"}
    local repoDst=${2:?"No destination set"}
    local repoBranch=${3:-"master"}

    if [ ! -z "$3" ]; then
        repoDst="${repoDst} (${repoBranch})"
    fi

    echo "Clone or pull if existing git repository"
    if [[ ! -d "${HOME}/${repoDst}" ]]; then
        git clone -b ${repoBranch} "${repoUrl}" "${HOME}/${repoDst}"
        chmod -R -w "${HOME}/${repoDst}"
    fi

    if [[ ! -h "${HOME}/work/Originale (nicht schreibbar)/${repoDst}" ]]; then
        echo "Create symbolic link in working directory"
        ln -s "${HOME}/${repoDst}" "${HOME}/work/Originale (nicht schreibbar)/${repoDst}"
    fi

    if [[ ! -d "${HOME}/work/${repoDst}" ]]; then
        echo "Create module folder in working directory"
        mkdir -p "${HOME}/work/${repoDst}"
    fi

    while IFS= read -r -d '' folder; do
        candidate="$HOME/work/${repoDst}/$(basename "$folder")"
        if [[ ! -e "$candidate" ]]; then
            echo "Copy $(basename "$folder") into working directory"
            cp -r "${folder}" "${candidate}"
        fi
    done < <(find "${HOME}/${repoDst}" -maxdepth 1 -mindepth 1 -not -path '*/\.*' -not -name 'README.md' -print0)

    chmod -R +w "${HOME}/work/${repoDst}"
}
export -f pull_repository

prepare_originals() {
    if [[ ! -d "${HOME}/work/Originale (nicht schreibbar)" ]]; then
        echo "Create originals folder in working directory"
        mkdir -p "${HOME}/work/Originale (nicht schreibbar)"
    else
        echo "Clearing originals folder in working directory"
        rm -f "${HOME}/work/Originale (nicht schreibbar)/"*
    fi
}

prepare_originals
pull_repository "${MODULE_GIT_REPO}" "${MODULE_FOLDER}"
if [ -f "${HOME}/work/.branches" ]; then
    cat "${HOME}/work/.branches" | xargs -n 1 bash -c 'pull_repository "${MODULE_GIT_REPO}" "${MODULE_FOLDER}" $@' _
fi